==> RBioinf_1.4.0.zip: RBioinf/doc/RBioinf.R <==
###################################################
### chunk number 1: ex1
###################################################
library(RBioinf)
setClass("object")
setClass("grid-layout", contains="object")
setClass("horizontal-grid", contains="grid-layout")
setClass("vertical-grid", contains="grid-layout")
setClass("hv-grid", contains=c("horizontal-grid", "vertical-grid"))

LPO("hv-grid")



###################################################
### chunk number 2: cpotest
###################################################
computeClassLinearization("object")
computeClassLinearization("grid-layout")
computeClassLinearization("vertical-grid")


###################################################
### chunk number 3: s1
###################################################
setClass("vh-grid", contains=c("vertical-grid", "horizontal-grid"))

setClass("confused", contains=c("hv-grid", "vh-grid"))

LPO("vh-grid")
tryCatch(LPO("confused"), error=function(x) "this one failed")



###################################################
### chunk number 4: plotconfG
###################################################
 library(Rgraphviz)
 confG = class2Graph("confused")

 cGa = makeNodeAttrs(confG, shape="ellipse", fill="grey", width=4)

 plot(confG, nodeAttrs=cGa)



###################################################
### chunk number 5: showExtends
###################################################

 setClass("a")
 setClass("b")
 setClass("c", contains = c("a", "b"))
 setClass("d", contains = c("b", "a"))

 extends("c")
 extends("d")

 setClass("e", contains=c("c", "d"))



###################################################
### chunk number 6: sCdemo
###################################################

getAllSuperClasses(getClass("e"))

cD = superClassDepth(getClass("e"))
cD$label
cD$depth

superClasses(getClass("e"))



###################################################
### chunk number 7: c2G
###################################################

cH = class2Graph("e")



###################################################
### chunk number 8: editWin
###################################################

 setClass("pane", contains="object")
 setClass("editing-mixin", contains="object")
 setClass("scrolling-mixin", contains="object")

 setClass("scrollable-pane", contains=c("pane", "scrolling-mixin"))
 setClass("editable-pane", contains=c("pane", "editing-mixin"))

 setClass("editable-scrollable-pane",
         contains=c("scrollable-pane", "editable-pane"))



###################################################
### chunk number 9: LPOseW
###################################################

LPO("editable-scrollable-pane")
LPO("editable-scrollable-pane", C3=TRUE)



###################################################
### chunk number 10: eWgraph
###################################################
 eWG = class2Graph("editable-scrollable-pane")

 eWGattrs = makeNodeAttrs(eWG, shape="ellipse", fill="grey", width=4)

 plot(eWG, nodeAttrs=eWGattrs)



###################################################
### chunk number 11: 
###################################################
sessionInfo()

==> RBioinf_1.10.0.zip: RBioinf/doc/RBioinf.R <==
###################################################
### chunk number 1: ex1
###################################################
#line 118 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp0LzdeO/R.INSTALL3c296a52/RBioinf/inst/doc/RBioinf.Rnw"
library(RBioinf)
setClass("object")
setClass("grid-layout", contains="object")
setClass("horizontal-grid", contains="grid-layout")
setClass("vertical-grid", contains="grid-layout")
setClass("hv-grid", contains=c("horizontal-grid", "vertical-grid"))

LPO("hv-grid")



###################################################
### chunk number 2: cpotest
###################################################
#line 130 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp0LzdeO/R.INSTALL3c296a52/RBioinf/inst/doc/RBioinf.Rnw"
computeClassLinearization("object")
computeClassLinearization("grid-layout")
computeClassLinearization("vertical-grid")


###################################################
### chunk number 3: s1
###################################################
#line 152 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp0LzdeO/R.INSTALL3c296a52/RBioinf/inst/doc/RBioinf.Rnw"
setClass("vh-grid", contains=c("vertical-grid", "horizontal-grid"))

setClass("confused", contains=c("hv-grid", "vh-grid"))

LPO("vh-grid")
tryCatch(LPO("confused"), error=function(x) "this one failed")



###################################################
### chunk number 4: plotconfG
###################################################
#line 165 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp0LzdeO/R.INSTALL3c296a52/RBioinf/inst/doc/RBioinf.Rnw"
 library(Rgraphviz)
 confG = class2Graph("confused")

 cGa = makeNodeAttrs(confG, shape="ellipse", fill="grey", width=4)

 plot(confG, nodeAttrs=cGa)



###################################################
### chunk number 5: showExtends
###################################################
#line 236 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp0LzdeO/R.INSTALL3c296a52/RBioinf/inst/doc/RBioinf.Rnw"

 setClass("a")
 setClass("b")
 setClass("c", contains = c("a", "b"))
 setClass("d", contains = c("b", "a"))

 extends("c")
 extends("d")

 setClass("e", contains=c("c", "d"))



###################################################
### chunk number 6: sCdemo
###################################################
#line 259 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp0LzdeO/R.INSTALL3c296a52/RBioinf/inst/doc/RBioinf.Rnw"

getAllSuperClasses(getClass("e"))

cD = superClassDepth(getClass("e"))
cD$label
cD$depth

superClasses(getClass("e"))



###################################################
### chunk number 7: c2G
###################################################
#line 274 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp0LzdeO/R.INSTALL3c296a52/RBioinf/inst/doc/RBioinf.Rnw"

cH = class2Graph("e")



###################################################
### chunk number 8: editWin
###################################################
#line 279 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp0LzdeO/R.INSTALL3c296a52/RBioinf/inst/doc/RBioinf.Rnw"

 setClass("pane", contains="object")
 setClass("editing-mixin", contains="object")
 setClass("scrolling-mixin", contains="object")

 setClass("scrollable-pane", contains=c("pane", "scrolling-mixin"))
 setClass("editable-pane", contains=c("pane", "editing-mixin"))

 setClass("editable-scrollable-pane",
         contains=c("scrollable-pane", "editable-pane"))



###################################################
### chunk number 9: LPOseW
###################################################
#line 300 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp0LzdeO/R.INSTALL3c296a52/RBioinf/inst/doc/RBioinf.Rnw"

LPO("editable-scrollable-pane")
LPO("editable-scrollable-pane", C3=TRUE)



###################################################
### chunk number 10: eWgraph
###################################################
#line 310 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp0LzdeO/R.INSTALL3c296a52/RBioinf/inst/doc/RBioinf.Rnw"
 eWG = class2Graph("editable-scrollable-pane")

 eWGattrs = makeNodeAttrs(eWG, shape="ellipse", fill="grey", width=4)

 plot(eWG, nodeAttrs=eWGattrs)



###################################################
### chunk number 11: 
###################################################
#line 325 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp0LzdeO/R.INSTALL3c296a52/RBioinf/inst/doc/RBioinf.Rnw"
sessionInfo()
